<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Hedwix Outreach
 */

if ( ! function_exists( 'hedwix_outreach_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function hedwix_outreach_posted_on() {
		$show_meta_date   = true;
		$show_meta_author = true;

		$posted_on = '';
		if ( true === $show_meta_date ) {
			$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

			$time_string = sprintf( $time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() )
			);

			$posted_on = sprintf(
				'%s',
				'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
			);
		}

		$byline = '';
		if ( true === $show_meta_author ) {
			$byline = sprintf(
				'%s',
				'<span class="author vcard"> By ' . esc_html( get_the_author() ) . '</span>'
			);
		}

    if ( ! empty( $byline ) ) {
      echo '<span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.
    }

    echo '<span class="sep"> | </span>'; // separator

		if ( ! empty( $posted_on ) ) {
			echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.
		}

	}
endif;

if ( ! function_exists( 'hedwix_outreach_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function hedwix_outreach_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			$show_meta_categories = true;
			if ( true === $show_meta_categories ) {
				/* Translators: used between list items, there is a space after the comma. */
				$categories_list = get_the_category_list( esc_html__( ', ', 'hedwix-outreach' ) );
				if ( $categories_list && hedwix_outreach_categorized_blog() ) {
					printf( '<span class="cat-links">%1$s</span>', $categories_list ); // WPCS: XSS OK.
				}
			}
			$show_meta_tags = true;
			if ( true === $show_meta_tags ) {
				/* Translators: used between list items, there is a space after the comma. */
				$tags_list = get_the_tag_list( '', esc_html__( ', ', 'hedwix-outreach' ) );
				if ( $tags_list ) {
					printf( '<span class="tags-links">%1$s</span>', $tags_list ); // WPCS: XSS OK.
				}
			}
		}
	}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function hedwix_outreach_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'hedwix_outreach_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'hedwix_outreach_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so hedwix_outreach_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so hedwix_outreach_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in hedwix_outreach_categorized_blog.
 */
function hedwix_outreach_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}	
	delete_transient( 'hedwix_outreach_categories' );
}
add_action( 'edit_category', 'hedwix_outreach_category_transient_flusher' );
add_action( 'save_post',     'hedwix_outreach_category_transient_flusher' );

if ( ! function_exists( 'hedwix_outreach_posted_on_custom' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function hedwix_outreach_posted_on_custom() {

    global $post;
    
    // start echo author

    $byline = sprintf( '<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( $post->post_author ) ) . '"> By ' . esc_html( get_the_author_meta( 'display_name', $post->post_author ) ) . '</a></span>'
    );
    echo '<span class="byline"> ' . wp_kses_post( $byline ) . '</span>';

    // end echo author

    echo '<span class="sep"> | </span>'; // separator

    // start echo post date

		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';		

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() )
		);

		$posted_on = sprintf( '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

    echo '<span class="posted-on">' . wp_kses_post( $posted_on ) . '</span>';
    
    // end echo post date
	}

endif;
